@@ -121,7 +121,7 @@ class _InstructionContainer:
 
             elif inst['cmd'] == 'by':
 
-                def buildgen(pinst, inst):
+                def buildgen(inst):
                     cols = inst['cols']
                     pgen = genfns[-1]
 
@@ -132,19 +132,19 @@ class _InstructionContainer:
                                 _insert(c, 'temp', pgen())
                                 yield from _fetch(c, 'temp', cols)
                         finally:
-                            # must close the file descriptor to delete it 
+                            # must close the file descriptor to delete it
                             os.close(tmpdbfd)
                             if Path(tmpdb).is_file():
                                 os.remove(tmpdb)
                     return gen
 
-                genfns.append(buildgen(pinst, inst))
+                genfns.append(buildgen(inst))
 
             elif inst['cmd'] == 'merge':
-                if not ('by' in pinst['cmd']):
+                if not 'by' in pinst['cmd']:
                     raise ValueError("Must be grouped by columns before merge")
 
-                def buildgen(pinst, inst):
+                def buildgen(inst):
                     fn = _fn2gen(inst['fn'])
                     pgen = genfns[-1]
 
@@ -153,11 +153,11 @@ class _InstructionContainer:
 
                     return gen
 
-                genfns.append(buildgen(pinst, inst))
+                genfns.append(buildgen(inst))
 
             elif inst['cmd'] == 'concat':
 
-                def buildgen(pinst, inst):
+                def buildgen(inst):
                     pgen = genfns[-1]
 
                     def gen():
@@ -166,7 +166,7 @@ class _InstructionContainer:
                         for r in _inst2iter(inst['other']):
                             yield r
                     return gen
-                genfns.append(buildgen(pinst, inst))
+                genfns.append(buildgen(inst))
 
         yield from genfns[-1]()
 
